@@ -16,15 +16,17 @@ class FieldDiff(BasePolarion):
         before (anyType)
         collection (boolean)
         field_name (string)
-        removed (ArrayOf_xsd_anyType)
-"""
-    _cls_suds_map = {"added": "added",
-                     "after": "after",
-                     "before": "before",
-                     "collection": "collection",
-                     "field_name": "fieldName",
-                     "removed": "removed",
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        removed (ArrayOf_xsd_anyType)"""
+
+    _cls_suds_map = {
+        "added": "added",
+        "after": "after",
+        "before": "before",
+        "collection": "collection",
+        "field_name": "fieldName",
+        "removed": "removed",
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "tracker_client"
     _obj_struct = "tns3:FieldDiff"
