@@ -11,10 +11,12 @@ class Properties(BasePolarion):
     """Object to handle the Polarion WSDL tns4:Properties class
 
     Attributes:
-        property (property)
-"""
-    _cls_suds_map = {"property": "property",
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        property (property)"""
+
+    _cls_suds_map = {
+        "property": "property",
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "builder_client"
     _obj_struct = "tns4:Properties"
