@@ -17,19 +17,20 @@ class SignatureContext(BasePolarion):
         signatures (ArrayOfSignature)
         target_status_id (string)
         transition_data_revision (string)
-        user (User)
-"""
-    _cls_suds_map = {"transition_data_revision": "transitionDataRevision",
-                     "signatures":
-                     {"field_name": "signatures",
-                      "is_array": True,
-                      "cls": Signature,
-                      "arr_cls": ArrayOfSignature,
-                      "inner_field_name": "Signature"},
-                     "target_status_id": "targetStatusId",
-                     "user":
-                     {"field_name": "user",
-                      "cls": User}}
+        user (User)"""
+
+    _cls_suds_map = {
+        "transition_data_revision": "transitionDataRevision",
+        "signatures": {
+            "field_name": "signatures",
+            "is_array": True,
+            "cls": Signature,
+            "arr_cls": ArrayOfSignature,
+            "inner_field_name": "Signature",
+        },
+        "target_status_id": "targetStatusId",
+        "user": {"field_name": "user", "cls": User},
+    }
     _obj_client = "test_management_client"
     _obj_struct = "tns4:SignatureContext"
 
