@@ -18,21 +18,22 @@ class WorkRecord(BasePolarion):
         work_record_id (string)
         time_spent (duration)
         type (EnumOptionId)
-        user (User)
-"""
-    _cls_suds_map = {"comment": "comment",
-                     "date": "date",
-                     "work_record_id": "id",
-                     "time_spent": "timeSpent",
-                     "type":
-                     {"field_name": "type",
-                      "cls": EnumOptionId,
-                      "enum_id": "work-record-type"},
-                     "user":
-                     {"field_name": "user",
-                      "cls": User},
-                     "uri": "_uri",
-                     "_unresolved": "_unresolved"}
+        user (User)"""
+
+    _cls_suds_map = {
+        "comment": "comment",
+        "date": "date",
+        "work_record_id": "id",
+        "time_spent": "timeSpent",
+        "type": {
+            "field_name": "type",
+            "cls": EnumOptionId,
+            "enum_id": "work-record-type",
+        },
+        "user": {"field_name": "user", "cls": User},
+        "uri": "_uri",
+        "_unresolved": "_unresolved",
+    }
     _obj_client = "builder_client"
     _obj_struct = "tns5:WorkRecord"
 
